@@ -804,6 +804,14 @@ static PyObject* Fprofile_StartTrace(PyObject* obj, PyObject* args, PyObject* kw
         }
     }
 
+    if (moduleConfiguration.pid != 0) {
+        // This can be triggered by running `functiontrace.begin_tracing()`
+        // from inside a process that's already being traced.
+        // We'll fail in this situation, but might as well print a mildly
+        // helpful error message here.
+        perror("Functiontrace doubly initialized! Aborting.");
+        exit(-1);
+    }
     moduleConfiguration.pid = getpid();
 
     // Mark that we'll need to forget some information on forks.  In
@@ -1099,4 +1107,3 @@ static void Fprofile_ResetThreadState(void) {
     moduleConfiguration.pid = getpid();
     Fprofile_CreateThreadState();
 }
-
